@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::RewriteVersion::Transitional; # git description: v0.004-26-g8126cd3
-# ABSTRACT: ease the transition to [RewriteVersion] in your distribution
+package Dist::Zilla::Plugin::RewriteVersion::Transitional; # git description: v0.005-10-g676a4ff
+# ABSTRACT: Ease the transition to [RewriteVersion] in your distribution
 # KEYWORDS: plugin version rewrite munge module
-# vim: set ts=8 sts=4 sw=4 tw=78 et :
+# vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.005';
+our $VERSION = '0.006';
 
 use Moose;
 extends 'Dist::Zilla::Plugin::RewriteVersion';
@@ -14,6 +14,7 @@ with 'Dist::Zilla::Role::InsertVersion';
 use Moose::Util::TypeConstraints 'role_type';
 use Dist::Zilla::Util;
 use Module::Runtime 'use_module';
+use Term::ANSIColor 'colored';
 use namespace::autoclean;
 
 has fallback_version_provider => (
@@ -58,7 +59,9 @@ around dump_config => sub
     my $config = $self->$orig;
 
     $config->{+__PACKAGE__} = {
-        map { $_ => $self->$_ } qw(fallback_version_provider _fallback_version_provider_args),
+        $self->_using_fallback_version_provider
+            ? ( map { $_ => $self->$_ } qw(fallback_version_provider _fallback_version_provider_args) )
+            : ()
     };
 
     $config->{ $self->fallback_version_provider } = $self->_fallback_version_provider_obj->dump_config
@@ -81,12 +84,18 @@ around provide_version => sub
     return $self->_fallback_version_provider_obj->provide_version;
 };
 
+my $warned_underscore;
 around rewrite_version => sub
 {
     my $orig = shift;
     my $self = shift;
     my ($file, $version) = @_;
 
+    $self->log([
+        colored('%s is a dangerous $VERSION to use without stripping the underscore on a subsequent line!', 'yellow'),
+        $version,
+    ]) if $version =~ /_/ and not $warned_underscore++;
+
     # update existing our $VERSION = '...'; entry
     return 1 if $self->$orig($file, $version);
 
@@ -103,11 +112,11 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::Plugin::RewriteVersion::Transitional - ease the transition to [RewriteVersion] in your distribution
+Dist::Zilla::Plugin::RewriteVersion::Transitional - Ease the transition to [RewriteVersion] in your distribution
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
@@ -149,6 +158,10 @@ L<[RewriteVersion]|Dist::Zilla::Plugin::RewriteVersion> would.
 You would then use L<[BumpVersionAfterRelease::Transitional]|Dist::Zilla::Plugin::BumpVersionAfterRelease::Transitional>
 to increment the C<$VERSION> in the F<.pm> files in the repository.
 
+B<Note:> If there is more than one package in a single file, if there was
+I<any> C<$VERSION> declaration in the file, no additional declarations are
+added for the other packages, even if you are using the C<global> option.
+
 =head1 CONFIGURATION OPTIONS
 
 Configuration is the same as in
